// This file is part of RiscPkg-GenControl.
// Copyright  2004-2010 Graham Shaw.
// Distribution and use are subject to the GNU General Public License,
// a copy of which may be found in the file "<CommonLicences$Dir>.GPL-2"
// or at the URL "http://www.riscpkg.org/licences/GPL-2.txt".

#include <map>
#include <set>
#include <string>
#include <iostream>

#include "libpkg/binary_control.h"

using std::exception;
using std::map;
using std::string;
using std::cin;
using std::cout;
using std::cerr;
using std::endl;
using std::ws;
using pkg::binary_control;

int main(int argc,const char* argv[])
{
	// Parse argument list.
	if (argc!=2)
	{
		cerr << "Usage: riscpkg-gencontrol pkgname" << endl;
		return 0;
	}
	string pkgname(argv[1]);

	try
	{
		std::set<std::string> exclude;
		exclude.insert("Build-Depends");

		// Read source control record from cin.
		binary_control ctrlbase;
		cin >> ctrlbase;
		cin >> ws;

		// Create table of binary control records indexed by package name.
		map<string,binary_control> ctrltable;
		while (cin)
		{
			// Read binary control record from cin.
			binary_control ctrl;
			cin >> ctrl;

			// Merge source and binary control records.
			for (binary_control::const_iterator i=ctrlbase.begin();
				i!=ctrlbase.end();++i)
			{
				string key=(*i).first;
				string value=(*i).second;
				if ((ctrl.find(key)==ctrl.end())&&
					(exclude.find(key)==exclude.end()))
					ctrl[key]=value;
			}

			// Store record in table.
			ctrltable[ctrl.pkgname()]=ctrl;

			cin >> ws;
		}

		// Select record from table and write to cout.
		cout << ctrltable[pkgname];
	}
	catch (const exception& ex)
	{
		cout << "Exception: " << ex.what() << endl;
	}

	return 0;
}
